<?php

namespace Drupal\pinterest_widget\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Settings form for Social Autopost.
 */
class SaveButtonSettingsForm extends ConfigFormBase {
  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['pinterest_save_button.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'pinterest_widget.form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('pinterest_save_button.settings');

    $form['advanced_settings'] = [
      '#type' => 'details',
      '#title' => $this->t('Default Configurations'),
      '#open' => TRUE,
      '#description' => 'The default values will be auto populated on the fields and blocks.',
    ];

    $button_types = array(
      'round' => "Round",
      'large' => "Large",
    );

    $languages = array(
     "default" => "User's Default Language",
     "en" => "English",
     "cs" => "Czech",
     "da" => "Danish",
     "de" => "German",
     "el" => "Greek",
     "es" => "Spanish",
     "fi" => "Finnish",
     "fr" => "French",
     "hi" => "Hindu",
     "hu" => "Hungarian",
     "id" => "Indonesian",
     "it" => "Italian",
     "ja" => "Japanese",
     "ko" => "Korean",
     "ms" => "Malaysian",
     "nb" => "Norwegian",
     "nl" => "Dutch",
     "pl" => "Polish",
     "pt" => "Portuguese",
     "pt-br" => "Portuguese (Brazil)",
     "ro" => "Romanian",
     "ru" => "Russian",
     "sk" => "Slovak",
     "sv" => "Swedish",
     "tl" => "Tagalog",
     "th" => "Thai",
     "tr" => "Turkish",
     "uk" => "Ukrainian",
     "vi" => "Vietnamese"
   );

    $selected_button_types  = $config->get('button_types')??[];
    $language  = $config->get('language')??[];

    $form['advanced_settings']['button_types'] = array(
      '#type' => 'checkboxes',
      '#options' => $button_types,
      '#title' => $this->t('Button Types'),
      '#default_value' => $selected_button_types,
      '#description' => t('Select available opions for user subscription'),
    );
    $form['advanced_settings']['language'] = array(
      '#type' => 'select',
      '#options' => $languages,
      '#title' => $this->t('Language'),
      '#default_value' => $language,
      '#description' => t('User\'s Default Language will show a user the Save button in their own language. If their language is not supported, it will show in English. You can choose a language from the dropdown to always show the Save button in that language.'),
    );
    $form['advanced_settings']['language'] = array(
      '#type' => 'select',
      '#options' => $languages,
      '#title' => $this->t('Language'),
      '#default_value' => $language,
      '#description' => t('User\'s Default Language will show a user the Save button in their own language. If their language is not supported, it will show in English. You can choose a language from the dropdown to always show the Save button in that language.'),
    );

    $form['advanced_settings']['preview'] = array(
      "#title" => $this->t('Preview'),
      "#type" => "item" ,
      "#markup" => '<img height="239" width="320" src="https://farm8.staticflickr.com/7027/6851755809_df5b2051c9_z.jpg">'
    );

    $form['#attached']['library'][] = 'pinterest_widget/pinterest_widget';

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();

    $config_data = $this->config('pinterest_save_button.settings')
    ->set('button_types', $values['button_types'])
    ->set('language', $values['language']);

    $config_data->save();

    drupal_flush_all_caches();

    parent::submitForm($form, $form_state);
  }

}
