<?php

namespace Drupal\pinterest_widget\Plugin\Block;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Block\BlockBase;
use Drupal\Core\Block\BlockPluginInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\file\Entity\File;

/**
 * Provides a 'Pinterest Board' Block.
 *
 * @Block(
 *   id = "pinterest_board",
 *   admin_label = @Translation("Pinterest Board"),
 *   category = @Translation("Pinterest Widget"),
 * )
 */
class PinterestBoardBlock extends BlockBase implements BlockPluginInterface
{
    /**
     * {@inheritdoc}
     */
    public function build()
    {

      $config = $this->getConfiguration();
      $pinterest_board_url = (isset($config['pinterest_board_url']))?$config['pinterest_board_url']:'';

      if($pinterest_board_url != '') {
        $size = (isset($config['size']))?$config['size']:'';

        switch ($size) {
          case 'sidebar':
          $datap_in_board_width = "150";
          $data_pin_scale_height = "800";
          $data_pin_scale_width = "60";

          break;

          case 'header':
          $datap_in_board_width = "900";
          $data_pin_scale_height = "120";
          $data_pin_scale_width = "115";

          break;

          case 'custom':
          $datap_in_board_width = (isset($config['image_width']))?$config['image_width']:'400';
          $data_pin_scale_height = (isset($config['board_height']))?$config['board_height']:'240';
          $data_pin_scale_width = (isset($config['board_width']))?$config['board_width']:'80';
          break;

          default:
          $datap_in_board_width = "400";
          $data_pin_scale_height = "240";
          $data_pin_scale_width = "80";
          break;
        }

        $text = '<a data-pin-do="embedBoard" data-pin-board-width="'.$datap_in_board_width.'" data-pin-scale-height="'.$data_pin_scale_height.'" data-pin-scale-width="'.$data_pin_scale_width.'" href="'.$pinterest_board_url.'"></a>';

        $result_data = [
          '#type' => 'processed_text',
          '#text' => $text,
          '#format' => 'full_html',
        ];

        return $result_data;

      }
    }

    /**
     * {@inheritdoc}
     */
    public function blockForm($form, FormStateInterface $form_state)
    {

      $form = parent::blockForm($form, $form_state);

      $config = $this->getConfiguration();
      $pinterest_config = \Drupal::config('pinterest_board.settings');
      $config_pinterest_board_url = $pinterest_config->get('pinterest_board_url')??'';
      $config_size = $pinterest_config->get('size')??'';
      $config_image_width = $pinterest_config->get('image_width')??'';
      $config_board_height = $pinterest_config->get('board_height')??'';
      $config_board_width = $pinterest_config->get('board_width')??'';

      $pinterest_board_url = $config['pinterest_board_url']??$config_pinterest_board_url;
      $size = $config['size']??$config_size;
      $image_width = $config['image_width']??$config_image_width;
      $board_height = $config['board_height']??$config_board_height;
      $board_width = $config['board_width']??$config_board_width;

      $selected_size  = $pinterest_config->get('size')??[];

      $form += [
        '#title' => $this->t('Pinterest Board '.$delta_count),
        '#type' => 'details',
        '#open' => TRUE,
      ];

      $field_index = "settings[size]";

      $form['pinterest_board_url'] = [
        '#type' => 'textfield',
        '#title' => $this->t('Pinterest board URL'),
        '#default_value' => $pinterest_board_url,
        '#description' => $this->t('Pin URL. For eg. https://www.pinterest.com/pinterest/official-news/')
      ];

      $sizes = array(
        'square' => 'Square',
        'sidebar' => 'Sidebar',
        'header' => 'Header',
        'custom' => 'Create'
      );

      $form['size'] = array(
        '#type' => 'select',
        '#options' => $sizes,
        '#title' => $this->t('Size'),
        '#default_value' => $size,
        '#description' => t('Select available opions for user subscription'),
      );

      $form['image_width'] = [
        '#type' => 'number',
        '#title' => $this->t('Image width'),
        '#default_value' => $image_width,
        '#states' => array(
          'visible' => array(
            ':input[name="'.$field_index.'"]' => array(
              'value' => 'custom',
            ),
          ),
        ),
        '#description' => $this->t('The default Image width is 80')
      ];
      $form['board_height'] = [
        '#type' => 'number',
        '#title' => $this->t('Board height'),
        '#default_value' => $board_height,
        '#states' => array(
          'visible' => array(
            ':input[name="'.$field_index.'"]' => array(
              'value' => 'custom',
            ),
          ),
        ),
        '#description' => $this->t('The default Board height is 240')
      ];
      $form['board_width'] = [
        '#type' => 'number',
        '#title' => $this->t('Board width'),
        '#default_value' => $board_width,
        '#states' => array(
          'visible' => array(
            ':input[name="'.$field_index.'"]' => array(
              'value' => 'custom',
            ),
          ),
        ),
        '#description' => $this->t('The default Board width is 400')
      ];

      return $form;
    }

    /**
     * {@inheritdoc}
     */
    public function blockSubmit($form, FormStateInterface $form_state)
    {
      parent::blockSubmit($form, $form_state);
      $pinterest_board_url = $form_state->getValue('pinterest_board_url');
      $size = $form_state->getValue('size');
      $image_width = $form_state->getValue('image_width');
      $board_height = $form_state->getValue('board_height');
      $board_width = $form_state->getValue('board_width');

      $this->setConfigurationValue('pinterest_board_url',$pinterest_board_url);
      $this->setConfigurationValue('size',$size);
      $this->setConfigurationValue('image_width',$image_width);
      $this->setConfigurationValue('board_height',$board_height);
      $this->setConfigurationValue('board_width',$board_width);
    }


    /**
     * {@inheritdoc}
     */
    public function blockValidate($form, FormStateInterface $form_state)
    {

    }

    /**
     * {@inheritdoc}
     * return 0 If you want to disable caching for this block.
     */
    public function getCacheMaxAge()
    {

      return 0;
    }

    /**
     * {@inheritdoc}
     */
    public function access(AccountInterface $account, $return_as_object = FALSE)
    {
      return AccessResult::allowedIfHasPermission($account, 'access content');
    }

  }