<?php

namespace Drupal\pinterest_widget\Plugin\Block;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Block\BlockBase;
use Drupal\Core\Block\BlockPluginInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\file\Entity\File;

/**
 * Provides a 'Pinterest Follow' Block.
 *
 * @Block(
 *   id = "pinterest_follow",
 *   admin_label = @Translation("Pinterest Follow"),
 *   category = @Translation("Pinterest Widget"),
 * )
 */
class PinterestFollowBlock extends BlockBase implements BlockPluginInterface
{
    /**
     * {@inheritdoc}
     */
    public function build()
    {

      $config = $this->getConfiguration();

      $pinterest_user_url = (isset($config['pinterest_user_url']))?$config['pinterest_user_url']:'';
      $full_name = (isset($config['full_name']))?$config['full_name']:'';
      if($pinterest_user_url != '') {
        $text = '<a data-pin-do="buttonFollow" href="'. $pinterest_user_url .'">'.$full_name.'</a>';
        $result_data = [
          '#type' => 'processed_text',
          '#text' => $text,
          '#format' => 'full_html',
        ];

        return $result_data;
      }

    }

    /**
     * {@inheritdoc}
     */
    public function blockForm($form, FormStateInterface $form_state)
    {

      $form = parent::blockForm($form, $form_state);

      $config = $this->getConfiguration();

      $pinterest_config = \Drupal::config('pinterest_follow.settings');
      $pinterest_user_url = $pinterest_config->get('pinterest_user_url')??'';
      $full_name = $pinterest_config->get('full_name')??'';

      $pinterest_user_url = $value['pinterest_user_url']??$pinterest_user_url;
      $full_name = $value['full_name']??$full_name;

      $form += [
        '#type' => 'details',
        '#open' => TRUE,
        '#title' => $this->t('Pinterest Follow')
      ];

      $form['pinterest_user_url'] = [
        '#type' => 'textfield',
        '#default_value' => $pinterest_user_url,
        '#title' => $this->t('Pinterest user URL'),
        '#description' => $this->t('Pinterest profile url. For eg. https://www.pinterest.com/pinterest/')
      ];
      $form['full_name'] = [
        '#type' => 'textfield',
        '#default_value' => $full_name,
        '#title' => $this->t('Full name'),
        '#description' => $this->t('Pinterest profle name. For eg. Pinterest')
      ];

      return $form;
    }

    /**
     * {@inheritdoc}
     */
    public function blockSubmit($form, FormStateInterface $form_state)
    {
      parent::blockSubmit($form, $form_state);
      $pinterest_user_url = $form_state->getValue('pinterest_user_url');
      $full_name = $form_state->getValue('full_name');

      $this->setConfigurationValue('pinterest_user_url',$pinterest_user_url);
      $this->setConfigurationValue('full_name',$full_name);
    }


    /**
     * {@inheritdoc}
     */
    public function blockValidate($form, FormStateInterface $form_state)
    {

    }

    /**
     * {@inheritdoc}
     * return 0 If you want to disable caching for this block.
     */
    public function getCacheMaxAge()
    {

      return 0;
    }

    /**
     * {@inheritdoc}
     */
    public function access(AccountInterface $account, $return_as_object = FALSE)
    {
      return AccessResult::allowedIfHasPermission($account, 'access content');
    }

  }