<?php

namespace Drupal\pinterest_widget\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'pinterest_pin_widget' widget.
 *
 * @FieldWidget(
 *   id = "pinterest_pin_widget",
 *   label = @Translation("Pinterest Pin Default Widget"),
 *   field_types = {
 *     "pinterest_pin_fieldtype"
 *   }
 * )
 */
class PinterestPinWidget extends WidgetBase {

  /**
   * Gets the initial values for the widget.
   *
   * This is a replacement for the disabled default values functionality.
   *
   * @return array
   *   The initial values, keyed by property.
   */
  protected function getInitialValues() {
    $initial_values = [
      'pin_url' => '',
      'pin_size' => '',
      'hide_description' => ''
    ];

    return $initial_values;
  }

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_featured_image) {
    $item = $items[$delta];
    $value = $item->getEntity()->isNew() ? $this->getInitialValues() : $item->toArray();

    $config = \Drupal::config('pinterest_pin.settings');
    $pin_url = $config->get('pin_url')??'';
    $pin_size = $config->get('pin_size')??'';
    $hide_description = $config->get('hide_description')??'';

    $pin_url = $value['pin_url']??$pin_url;
    $pin_size = $value['pin_size']??$pin_size;
    $hide_description = $value['hide_description']??$hide_description;

    $element += [
      '#type' => 'details',
      '#open' => TRUE,
    ];

    $pin_sizes = array(
      'small' => "Small",
      'medium' => "Medium",
      'large' => "Large",
    );

    $element['pin_url'] = [
      '#type' => 'textfield',
      '#default_value' => $pin_url,
      '#title' => $this->t('Pin URL'),
      '#description' => $this->t('Pin URL. For eg. https://www.pinterest.com/pin/99360735500167749/')
    ];
    $element['pin_size'] = array(
      '#type' => 'select',
      '#options' => $pin_sizes,
      '#title' => $this->t('Pin size'),
      '#default_value' => $pin_size,
      '#description' => t('Select available opions for user subscription'),
    );
    $element['hide_description'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Hide description'),
      '#default_value' => $hide_description,
      '#description' => $this->t('Hide Description')
    ];

    return $element;
  }


}
