<?php

namespace Drupal\pinterest_widget\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'pinterest_profile_widget' widget.
 *
 * @FieldWidget(
 *   id = "pinterest_profile_widget",
 *   label = @Translation("Pinterest Profile Default Widget"),
 *   field_types = {
 *     "pinterest_profile_fieldtype"
 *   }
 * )
 */
class PinterestProfileWidget extends WidgetBase {

  /**
   * Gets the initial values for the widget.
   *
   * This is a replacement for the disabled default values functionality.
   *
   * @return array
   *   The initial values, keyed by property.
   */
  protected function getInitialValues() {
    $initial_values = [
      'pinterest_user_url' => '',
      'size' => '',
      'image_width' => '',
      'board_height' => '',
      'board_width' => ''
    ];

    return $initial_values;
  }

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_featured_image) {
    $item = $items[$delta];

    $count_items = $items->count();

    $value = array();

    $value = $item->getEntity()->isNew() ? $this->getInitialValues() : $item->toArray();

    $config = \Drupal::config('pinterest_profile.settings');
    $config_pinterest_user_url = $config->get('pinterest_user_url')??'';
    $config_size = $config->get('size')??'';
    $config_image_width = $config->get('image_width')??'';
    $config_board_height = $config->get('board_height')??'';
    $config_board_width = $config->get('board_width')??'';

    $delta_count = '';
    if($count_items > 1) {
      $config_pinterest_user_url = '';
      $config_image_width = '';
      $config_board_height = '';
      $config_board_width = '';
      $delta_count = $delta;
    }

    $pinterest_user_url = $value['pinterest_user_url']??$config_pinterest_user_url;
    $size = $value['size']??$size;
    $image_width = $value['image_width']??$config_image_width;
    $board_height = $value['board_height']??$config_board_height;
    $board_width = $value['board_width']??$config_board_width;

    $selected_size  = $config->get('size')??[];

    $element = array();


    $element += [
      '#title' => $this->t('Pinterest Profile '.$delta_count),
      '#type' => 'details',
      '#open' => TRUE,
    ];

    $field_index = "field_pinterest_profile[".$delta."][size]";

    $element['pinterest_user_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Pinterest user URL'),
      '#default_value' => $pinterest_user_url,
      '#description' => $this->t('Pin URL. For eg. https://www.pinterest.com/pinterest/')
    ];

    $sizes = array(
      'square' => 'Square',
      'sidebar' => 'Sidebar',
      'header' => 'Header',
      'custom' => 'Create'
    );

    $element['size'] = array(
      '#type' => 'select',
      '#options' => $sizes,
      '#title' => $this->t('Size'),
      '#default_value' => $size,
      '#description' => t('Select available opions for user subscription'),
    );

    $element['image_width'] = [
      '#type' => 'number',
      '#title' => $this->t('Image width'),
      '#default_value' => $image_width,
      '#states' => array(
        'visible' => array(
          ':input[name="'.$field_index.'"]' => array(
            'value' => 'custom',
          ),
        ),
      ),
      '#description' => $this->t('The default Image width is 80')
    ];
    $element['board_height'] = [
      '#type' => 'number',
      '#title' => $this->t('Board height'),
      '#default_value' => $board_height,
      '#states' => array(
        'visible' => array(
          ':input[name="'.$field_index.'"]' => array(
            'value' => 'custom',
          ),
        ),
      ),
      '#description' => $this->t('The default Board height is 240')
    ];
    $element['board_width'] = [
      '#type' => 'number',
      '#title' => $this->t('Board width'),
      '#default_value' => $board_width,
      '#states' => array(
        'visible' => array(
          ':input[name="'.$field_index.'"]' => array(
            'value' => 'custom',
          ),
        ),
      ),
      '#description' => $this->t('The default Board width is 400')
    ];

    return $element;
  }


}
